@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Africa/Cairo"] = {
-	"guess" : helpers.makeTestGuess("Africa/Cairo", { offset: true, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Africa/Cairo", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Africa/Cairo", { abbr: true }),
 
 	"1940" : helpers.makeTestYear("Africa/Cairo", [
 		["1940-07-14T21:59:59+00:00", "23:59:59", "EET", -120],
@@ -435,8 +438,6 @@ exports["Africa/Cairo"] = {
 		["2014-06-26T20:59:59+00:00", "23:59:59", "EEST", -180],
 		["2014-06-26T21:00:00+00:00", "23:00:00", "EET", -120],
 		["2014-07-31T21:59:59+00:00", "23:59:59", "EET", -120],
-		["2014-07-31T22:00:00+00:00", "01:00:00", "EEST", -180],
-		["2014-09-25T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2014-09-25T21:00:00+00:00", "23:00:00", "EET", -120]
+		["2014-07-31T22:00:00+00:00", "01:00:00", "EEST", -180]
 	])
 };
\ No newline at end of file
