@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Africa/Johannesburg"] = {
-	"guess" : helpers.makeTestGuess("Africa/Johannesburg", { offset: false, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Africa/Johannesburg", { offset: true, expect: "Africa/Cairo" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Africa/Johannesburg", { abbr: true }),
 
 	"1903" : helpers.makeTestYear("Africa/Johannesburg", [
 		["1903-02-28T22:29:59+00:00", "23:59:59", "SAST", -90],
@@ -20,10 +23,5 @@ exports["Africa/Johannesburg"] = {
 		["1943-03-20T23:00:00+00:00", "01:00:00", "SAST", -120],
 		["1943-09-18T23:59:59+00:00", "01:59:59", "SAST", -120],
 		["1943-09-19T00:00:00+00:00", "03:00:00", "SAST", -180]
-	]),
-
-	"1944" : helpers.makeTestYear("Africa/Johannesburg", [
-		["1944-03-18T22:59:59+00:00", "01:59:59", "SAST", -180],
-		["1944-03-18T23:00:00+00:00", "01:00:00", "SAST", -120]
 	])
 };
\ No newline at end of file
