@@ -191,8 +191,6 @@ exports["Africa/Windhoek"] = {
 
 	"2017" : helpers.makeTestYear("Africa/Windhoek", [
 		["2017-04-01T23:59:59+00:00", "01:59:59", "CAT", -120],
-		["2017-04-02T00:00:00+00:00", "01:00:00", "WAT", -60],
-		["2017-09-03T00:59:59+00:00", "01:59:59", "WAT", -60],
-		["2017-09-03T01:00:00+00:00", "03:00:00", "CAT", -120]
+		["2017-04-02T00:00:00+00:00", "01:00:00", "WAT", -60]
 	])
 };
\ No newline at end of file
