@@ -325,10 +325,5 @@ exports["Antarctica/Macquarie"] = {
 		["2009-04-04T16:00:00+00:00", "02:00:00", "AEST", -600],
 		["2009-10-03T15:59:59+00:00", "01:59:59", "AEST", -600],
 		["2009-10-03T16:00:00+00:00", "03:00:00", "AEDT", -660]
-	]),
-
-	"2010" : helpers.makeTestYear("Antarctica/Macquarie", [
-		["2010-04-03T15:59:59+00:00", "02:59:59", "AEDT", -660],
-		["2010-04-03T16:00:00+00:00", "03:00:00", "+11", -660]
 	])
 };
\ No newline at end of file
