@@ -8,11 +8,6 @@ exports["Asia/Barnaul"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Barnaul", { abbr: true }),
 
-	"1919" : helpers.makeTestYear("Asia/Barnaul", [
-		["1919-12-09T18:24:59+00:00", "23:59:59", "LMT", -335],
-		["1919-12-09T18:25:00+00:00", "00:25:00", "+06", -360]
-	]),
-
 	"1930" : helpers.makeTestYear("Asia/Barnaul", [
 		["1930-06-20T17:59:59+00:00", "23:59:59", "+06", -360],
 		["1930-06-20T18:00:00+00:00", "01:00:00", "+07", -420]
@@ -240,10 +235,5 @@ exports["Asia/Barnaul"] = {
 	"2014" : helpers.makeTestYear("Asia/Barnaul", [
 		["2014-10-25T18:59:59+00:00", "01:59:59", "+07", -420],
 		["2014-10-25T19:00:00+00:00", "01:00:00", "+06", -360]
-	]),
-
-	"2016" : helpers.makeTestYear("Asia/Barnaul", [
-		["2016-03-26T19:59:59+00:00", "01:59:59", "+06", -360],
-		["2016-03-26T20:00:00+00:00", "03:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
