@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Dacca"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Dacca", { offset: true, expect: "Asia/Dhaka" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Dacca", { abbr: true, expect: "Asia/Dhaka" }),
+
 	"1941" : helpers.makeTestYear("Asia/Dacca", [
 		["1941-09-30T18:06:39+00:00", "23:59:59", "HMT", -21200 / 60],
 		["1941-09-30T18:06:40+00:00", "00:36:40", "+0630", -390]
@@ -22,8 +27,6 @@ exports["Asia/Dacca"] = {
 
 	"2009" : helpers.makeTestYear("Asia/Dacca", [
 		["2009-06-19T16:59:59+00:00", "22:59:59", "+06", -360],
-		["2009-06-19T17:00:00+00:00", "00:00:00", "+07", -420],
-		["2009-12-31T16:59:59+00:00", "23:59:59", "+07", -420],
-		["2009-12-31T17:00:00+00:00", "23:00:00", "+06", -360]
+		["2009-06-19T17:00:00+00:00", "00:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
