@@ -8,11 +8,6 @@ exports["Asia/Seoul"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Seoul", { abbr: true }),
 
-	"1908" : helpers.makeTestYear("Asia/Seoul", [
-		["1908-03-31T15:32:07+00:00", "23:59:59", "LMT", -30472 / 60],
-		["1908-03-31T15:32:08+00:00", "00:02:08", "KST", -510]
-	]),
-
 	"1911" : helpers.makeTestYear("Asia/Seoul", [
 		["1911-12-31T15:29:59+00:00", "23:59:59", "KST", -510],
 		["1911-12-31T15:30:00+00:00", "00:30:00", "JST", -540]
@@ -84,8 +79,6 @@ exports["Asia/Seoul"] = {
 
 	"1988" : helpers.makeTestYear("Asia/Seoul", [
 		["1988-05-07T16:59:59+00:00", "01:59:59", "KST", -540],
-		["1988-05-07T17:00:00+00:00", "03:00:00", "KDT", -600],
-		["1988-10-08T16:59:59+00:00", "02:59:59", "KDT", -600],
-		["1988-10-08T17:00:00+00:00", "02:00:00", "KST", -540]
+		["1988-05-07T17:00:00+00:00", "03:00:00", "KDT", -600]
 	])
 };
\ No newline at end of file
