@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Singapore"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Singapore", { offset: true, expect: "Asia/Manila" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Singapore", { abbr: true, expect: "Asia/Manila" }),
+
 	"1905" : helpers.makeTestYear("Asia/Singapore", [
 		["1905-05-31T17:04:34+00:00", "23:59:59", "SMT", -24925 / 60],
 		["1905-05-31T17:04:35+00:00", "00:04:35", "+07", -420]
@@ -31,10 +36,5 @@ exports["Asia/Singapore"] = {
 	"1945" : helpers.makeTestYear("Asia/Singapore", [
 		["1945-09-11T14:59:59+00:00", "23:59:59", "+09", -540],
 		["1945-09-11T15:00:00+00:00", "22:30:00", "+0730", -450]
-	]),
-
-	"1981" : helpers.makeTestYear("Asia/Singapore", [
-		["1981-12-31T16:29:59+00:00", "23:59:59", "+0730", -450],
-		["1981-12-31T16:30:00+00:00", "00:30:00", "+08", -480]
 	])
 };
\ No newline at end of file
