@@ -8,11 +8,6 @@ exports["Asia/Tomsk"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Tomsk", { abbr: true }),
 
-	"1919" : helpers.makeTestYear("Asia/Tomsk", [
-		["1919-12-21T18:20:08+00:00", "23:59:59", "LMT", -20391 / 60],
-		["1919-12-21T18:20:09+00:00", "00:20:09", "+06", -360]
-	]),
-
 	"1930" : helpers.makeTestYear("Asia/Tomsk", [
 		["1930-06-20T17:59:59+00:00", "23:59:59", "+06", -360],
 		["1930-06-20T18:00:00+00:00", "01:00:00", "+07", -420]
@@ -240,10 +235,5 @@ exports["Asia/Tomsk"] = {
 	"2014" : helpers.makeTestYear("Asia/Tomsk", [
 		["2014-10-25T18:59:59+00:00", "01:59:59", "+07", -420],
 		["2014-10-25T19:00:00+00:00", "01:00:00", "+06", -360]
-	]),
-
-	"2016" : helpers.makeTestYear("Asia/Tomsk", [
-		["2016-05-28T19:59:59+00:00", "01:59:59", "+06", -360],
-		["2016-05-28T20:00:00+00:00", "03:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
