@@ -454,8 +454,6 @@ exports["Europe/Istanbul"] = {
 
 	"2016" : helpers.makeTestYear("Europe/Istanbul", [
 		["2016-03-27T00:59:59+00:00", "02:59:59", "EET", -120],
-		["2016-03-27T01:00:00+00:00", "04:00:00", "EEST", -180],
-		["2016-09-06T20:59:59+00:00", "23:59:59", "EEST", -180],
-		["2016-09-06T21:00:00+00:00", "00:00:00", "+03", -180]
+		["2016-03-27T01:00:00+00:00", "04:00:00", "EEST", -180]
 	])
 };
\ No newline at end of file
