@@ -8,11 +8,6 @@ exports["Hongkong"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Hongkong", { abbr: true, expect: "Asia/Hong_Kong" }),
 
-	"1904" : helpers.makeTestYear("Hongkong", [
-		["1904-10-29T16:23:17+00:00", "23:59:59", "LMT", -27402 / 60],
-		["1904-10-29T16:23:18+00:00", "00:23:18", "HKT", -480]
-	]),
-
 	"1941" : helpers.makeTestYear("Hongkong", [
 		["1941-03-31T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1941-03-31T19:30:00+00:00", "04:30:00", "HKST", -540],
@@ -246,8 +241,6 @@ exports["Hongkong"] = {
 
 	"1979" : helpers.makeTestYear("Hongkong", [
 		["1979-05-12T19:29:59+00:00", "03:29:59", "HKT", -480],
-		["1979-05-12T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1979-10-20T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1979-10-20T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1979-05-12T19:30:00+00:00", "04:30:00", "HKST", -540]
 	])
 };
\ No newline at end of file
