@@ -3,10 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Indian/Mauritius"] = {
-	"1906" : helpers.makeTestYear("Indian/Mauritius", [
-		["1906-12-31T20:09:59+00:00", "23:59:59", "LMT", -230],
-		["1906-12-31T20:10:00+00:00", "00:10:00", "+04", -240]
-	]),
+
+	"guess:by:offset" : helpers.makeTestGuess("Indian/Mauritius", { offset: true, expect: "Asia/Dubai" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Indian/Mauritius", { abbr: true, expect: "Asia/Dubai" }),
 
 	"1982" : helpers.makeTestYear("Indian/Mauritius", [
 		["1982-10-09T19:59:59+00:00", "23:59:59", "+04", -240],
@@ -21,10 +21,5 @@ exports["Indian/Mauritius"] = {
 	"2008" : helpers.makeTestYear("Indian/Mauritius", [
 		["2008-10-25T21:59:59+00:00", "01:59:59", "+04", -240],
 		["2008-10-25T22:00:00+00:00", "03:00:00", "+05", -300]
-	]),
-
-	"2009" : helpers.makeTestYear("Indian/Mauritius", [
-		["2009-03-28T20:59:59+00:00", "01:59:59", "+05", -300],
-		["2009-03-28T21:00:00+00:00", "01:00:00", "+04", -240]
 	])
 };
\ No newline at end of file
