@@ -8,11 +8,6 @@ exports["Pacific/Efate"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Efate", { abbr: true, expect: "Pacific/Norfolk" }),
 
-	"1912" : helpers.makeTestYear("Pacific/Efate", [
-		["1912-01-12T12:46:43+00:00", "23:59:59", "LMT", -40396 / 60],
-		["1912-01-12T12:46:44+00:00", "23:46:44", "+11", -660]
-	]),
-
 	"1983" : helpers.makeTestYear("Pacific/Efate", [
 		["1983-09-24T12:59:59+00:00", "23:59:59", "+11", -660],
 		["1983-09-24T13:00:00+00:00", "01:00:00", "+12", -720]
@@ -79,10 +74,5 @@ exports["Pacific/Efate"] = {
 		["1992-01-25T12:00:00+00:00", "23:00:00", "+11", -660],
 		["1992-10-24T12:59:59+00:00", "23:59:59", "+11", -660],
 		["1992-10-24T13:00:00+00:00", "01:00:00", "+12", -720]
-	]),
-
-	"1993" : helpers.makeTestYear("Pacific/Efate", [
-		["1993-01-23T11:59:59+00:00", "23:59:59", "+12", -720],
-		["1993-01-23T12:00:00+00:00", "23:00:00", "+11", -660]
 	])
 };
\ No newline at end of file
