@@ -17,16 +17,13 @@ exports["Pacific/Honolulu"] = {
 
 	"1942" : helpers.makeTestYear("Pacific/Honolulu", [
 		["1942-02-09T12:29:59+00:00", "01:59:59", "HST", 630],
-		["1942-02-09T12:30:00+00:00", "03:00:00", "HDT", 570]
+		["1942-02-09T12:30:00+00:00", "03:00:00", "HWT", 570]
 	]),
 
 	"1945" : helpers.makeTestYear("Pacific/Honolulu", [
-		["1945-09-30T11:29:59+00:00", "01:59:59", "HDT", 570],
+		["1945-08-14T22:59:59+00:00", "13:29:59", "HWT", 570],
+		["1945-08-14T23:00:00+00:00", "13:30:00", "HPT", 570],
+		["1945-09-30T11:29:59+00:00", "01:59:59", "HPT", 570],
 		["1945-09-30T11:30:00+00:00", "01:00:00", "HST", 630]
-	]),
-
-	"1947" : helpers.makeTestYear("Pacific/Honolulu", [
-		["1947-06-08T12:29:59+00:00", "01:59:59", "HST", 630],
-		["1947-06-08T12:30:00+00:00", "02:30:00", "HST", 600]
 	])
 };
\ No newline at end of file
