@@ -21,10 +21,5 @@ exports["Pacific/Norfolk"] = {
 	"1975" : helpers.makeTestYear("Pacific/Norfolk", [
 		["1975-03-01T13:29:59+00:00", "01:59:59", "+1230", -750],
 		["1975-03-01T13:30:00+00:00", "01:00:00", "+1130", -690]
-	]),
-
-	"2015" : helpers.makeTestYear("Pacific/Norfolk", [
-		["2015-10-03T14:29:59+00:00", "01:59:59", "+1130", -690],
-		["2015-10-03T14:30:00+00:00", "01:30:00", "+11", -660]
 	])
 };
\ No newline at end of file
