@@ -8,8 +8,8 @@ exports["Pacific/Saipan"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Saipan", { abbr: true, expect: "Pacific/Guam" }),
 
-	"2000" : helpers.makeTestYear("Pacific/Saipan", [
-		["2000-12-22T13:59:59+00:00", "23:59:59", "GST", -600],
-		["2000-12-22T14:00:00+00:00", "00:00:00", "ChST", -600]
+	"1900" : helpers.makeTestYear("Pacific/Saipan", [
+		["1900-12-31T14:20:59+00:00", "23:59:59", "LMT", -579],
+		["1900-12-31T14:21:00+00:00", "00:21:00", "GST", -600]
 	])
 };
\ No newline at end of file
